@@ -36,15 +36,28 @@ def _enrich(source: Union[str, bytes], tree: AstNode) -> None:
     comment_tokens = sorted(
         (x.start[0], x) for x in tokens if x.type == tokenize.COMMENT
     )
-    nodes = sorted(
-        (x.lineno, x.col_offset, x) for x in ast.walk(tree) if isinstance(x, ast.stmt)
-    )
+
+    if not comment_tokens:
+        return
+
+    nodes = {}
+    for node in ast.walk(tree):
+        if not isinstance(node, ast.stmt):
+            continue
+        if node.lineno not in nodes:
+            nodes[node.lineno] = [node]
+        else:
+            nodes[node.lineno].append(node)
+
+    node_lines = sorted(nodes)
+
     i = j = 0
-    while i < len(comment_tokens) and j < len(nodes):
+    while i < len(comment_tokens) and j < len(node_lines):
         t_lineno, token = comment_tokens[i]
-        n_lineno, _, node = nodes[j]
+        n_lineno = node_lines[j]
         if t_lineno <= n_lineno:
-            node.comments += (format_comment(token.string),)
+            for node in nodes[n_lineno]:
+                node.comments += (format_comment(token.string),)
             i += 1
         else:
             j += 1
